@@ -10,6 +10,7 @@
 #include "../deb-installer/utils/utils.h"
 #include "../deb-installer/utils/result.h"
 #include "../deb-installer/utils/hierarchicalverify.h"
+#include "../deb-installer/view/widgets/error_notify_dialog_helper.h"
 
 #include <stub.h>
 
@@ -186,7 +187,7 @@ void model_backend_markPackageForRemoval(const QString &)
     return;
 }
 
-void model_refreshOperatingPackageStatus(const DebListModel::PackageOperationStatus)
+void model_refreshOperatingPackageStatus(const Pkg::PackageOperationStatus)
 {
     return;
 }
@@ -536,14 +537,6 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_isDevelopMode)
     EXPECT_TRUE(m_debListModel->isDevelopMode());
 }
 
-TEST_F(ut_DebListModel_test, deblistmodel_UT_selectedIndexRow)
-{
-    QSignalSpy spy(m_debListModel->m_packagesManager, SIGNAL(signalMultDependPackages(DependsPair, bool)));
-    m_debListModel->m_packagesManager->m_packageMd5.insert(0, "sweat00001adscws1");
-    m_debListModel->selectedIndexRow(0);
-    EXPECT_EQ(1, spy.count());
-}
-
 TEST_F(ut_DebListModel_test, deblistmodel_UT_initPrepareStatus)
 {
     QStringList list;
@@ -551,7 +544,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_initPrepareStatus)
     m_debListModel->slotAppendPackage(list);
 
     m_debListModel->initPrepareStatus();
-    ASSERT_EQ(m_debListModel->m_packageOperateStatus[0], DebListModel::Prepare);
+    ASSERT_EQ(m_debListModel->m_packageOperateStatus[0], Pkg::PackageOperationStatus::Prepare);
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_index)
@@ -560,7 +553,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_index)
     list << "/";
     m_debListModel->slotAppendPackage(list);
 
-    ASSERT_EQ(m_debListModel->index(0).data(DebListModel::PackageDependsStatusRole).toInt(), DebListModel::DependsOk);
+    ASSERT_EQ(m_debListModel->index(0).data(DebListModel::PackageDependsStatusRole).toInt(), Pkg::DependsStatus::DependsOk);
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_getInstallFileSize)
@@ -655,6 +648,11 @@ ConflictResult ut_packageConflictStat()
     return ConflictResult::err("");
 }
 
+PackageDependsStatus getPackageDependsStatus(const int)
+{
+    return PackageDependsStatus::_break("");
+}
+
 TEST_F(ut_DebListModel_test, deblistmodel_UT_packageFailedReason)
 {
     QStringList list;
@@ -666,6 +664,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_packageFailedReason)
     stub.set(ADDR(PackagesManager, isArchError), model_package_isArchError1);
     stub.set(ADDR(PackageDependsStatus, isBreak), ut_model_isBreak);
     stub.set(ADDR(PackagesManager, packageConflictStat), ut_packageConflictStat);
+    stub.set(ADDR(PackagesManager, getPackageDependsStatus), getPackageDependsStatus);
     m_debListModel->packageFailedReason(0);
     EXPECT_TRUE(m_debListModel->packageFailedReason(0).contains("Broken dependencies"));
 }
@@ -680,40 +679,37 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_initRowStatus)
 
     m_debListModel->initRowStatus();
 
-    ASSERT_EQ(m_debListModel->m_packageOperateStatus.find("deb").value(), DebListModel::Waiting);
+    ASSERT_EQ(m_debListModel->m_packageOperateStatus.find("deb").value(), Pkg::PackageOperationStatus::Waiting);
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_checkSystemVersion_UosEnterprise)
 {
     stub.set(ADDR(Dtk::Core::DSysInfo, uosEditionType), model_uosEditionType_UosEnterprise);
-    m_debListModel->checkSystemVersion();
-    EXPECT_TRUE(m_debListModel->m_isDevelopMode);
+    EXPECT_TRUE(Utils::isDevelopMode());
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_checkSystemVersion_UosProfessional)
 {
     stub.set(ADDR(Dtk::Core::DSysInfo, uosEditionType), model_uosEditionType_UosProfessional);
-    m_debListModel->checkSystemVersion();
+    Utils::isDevelopMode();
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_checkSystemVersion_UosHome)
 {
     stub.set(ADDR(Dtk::Core::DSysInfo, uosEditionType), model_uosEditionType_UosHome);
-    m_debListModel->checkSystemVersion();
+    Utils::isDevelopMode();
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_checkSystemVersion_UosCommunity)
 {
     stub.set(ADDR(Dtk::Core::DSysInfo, uosEditionType), model_uosEditionType_UosCommunity);
-    m_debListModel->checkSystemVersion();
-    EXPECT_TRUE(m_debListModel->m_isDevelopMode);
+    EXPECT_TRUE(Utils::isDevelopMode());
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_checkSystemVersion_default)
 {
     stub.set(ADDR(Dtk::Core::DSysInfo, uosEditionType), model_uosEditionType_default);
-    m_debListModel->checkSystemVersion();
-    EXPECT_TRUE(m_debListModel->m_isDevelopMode);
+    EXPECT_TRUE(Utils::isDevelopMode());
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_checkDigitalSignature)
@@ -773,7 +769,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_checkDigitalSignature_03)
     m_debListModel->m_isDigitalVerify = true;
     stub.set((Utils::VerifyResultCode(*)(QString))ADDR(Utils, Digital_Verify), model_Digital_Verify2);
     ASSERT_TRUE(m_debListModel->checkDigitalSignature());
-    m_debListModel->showDevelopDigitalErrWindow(DebListModel::NoDigitalSignature);
+    m_debListModel->showDevelopDigitalErrWindow(Pkg::NoDigitalSignature);
     EXPECT_EQ(1, m_debListModel->preparedPackages().size());
 }
 
@@ -835,7 +831,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_onTransactionErrorOccurred)
     m_debListModel->m_operatingPackageMd5 = "deb";
     m_debListModel->m_packageOperateStatus.insert("deb", QApt::CommitError);
     m_debListModel->m_packageFailCode.insert("deb", QApt::FetchError);
-    m_debListModel->checkSystemVersion();
+    m_debListModel->m_isDevelopMode = Utils::isDevelopMode();
     m_debListModel->m_workerStatus = DebListModel::WorkerProcessing;
     m_debListModel->m_packageMd5.insert(0, "00000");
     m_debListModel->m_operatingIndex = 0;
@@ -845,7 +841,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_onTransactionErrorOccurred)
 
     m_debListModel->slotTransactionErrorOccurred();
     EXPECT_EQ(QApt::AuthError, m_debListModel->m_packageFailCode[m_debListModel->m_operatingPackageMd5]);
-    EXPECT_EQ(DebListModel::Failed, m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
+    EXPECT_EQ(Pkg::PackageOperationStatus::Failed, m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
     delete ut_sender();
 }
 
@@ -857,11 +853,11 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_DealDependResult)
 
     m_debListModel->slotDealDependResult(1, 0, "");
     m_debListModel->slotDealDependResult(2, 0, "");
-    EXPECT_EQ(DebListModel::Prepare, m_debListModel->m_packageOperateStatus["1"]);
+    EXPECT_EQ(Pkg::PackageOperationStatus::Prepare, m_debListModel->m_packageOperateStatus["1"]);
     m_debListModel->slotDealDependResult(3, 0, "");
     m_debListModel->slotDealDependResult(4, 0, "");
-    EXPECT_EQ(DebListModel::Prepare, m_debListModel->m_packageOperateStatus["1"]);
-    EXPECT_EQ(DebListModel::Prepare, m_debListModel->m_workerStatus);
+    EXPECT_EQ(Pkg::PackageOperationStatus::Prepare, m_debListModel->m_packageOperateStatus["1"]);
+    EXPECT_EQ(Pkg::PackageOperationStatus::Prepare, m_debListModel->m_workerStatus);
     m_debListModel->slotDealDependResult(5, 0, "");
     EXPECT_EQ("", m_debListModel->m_brokenDepend);
 }
@@ -869,7 +865,8 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_DealDependResult)
 TEST_F(ut_DebListModel_test, deblistmodel_UT_DealDependResult_VerifyDependsErr)
 {
     Stub tmpStub;
-    tmpStub.set(ADDR(DebListModel, showHierarchicalVerifyWindow), stub_DebListModel_showHierarchicalVerifyWindow_DoNothing);
+    tmpStub.set(ADDR(ErrorNotifyDialogHelper, showHierarchicalVerifyWindow),
+                stub_DebListModel_showHierarchicalVerifyWindow_DoNothing);
 
     g_VerifyDeependErrCount = 0;
     m_debListModel->slotDealDependResult(DebListModel::VerifyDependsErr, 0, "");
@@ -906,7 +903,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_bumpInstallIndex)
     EXPECT_EQ("", m_debListModel->m_operatingPackageMd5);
 }
 
-TEST_F(ut_DebListModel_test, deblistmodel_UT_bumpInstallIndex_showHierarchicalVerifyWindow)
+TEST_F(ut_DebListModel_test, deblistmodel_UT_slotInstallPackages_resetHierarchicalVerify)
 {
     stub.set(ADDR(DebListModel, installNextDeb), model_installNextDeb);
     m_debListModel->m_operatingIndex = 0;
@@ -914,12 +911,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_bumpInstallIndex_showHierarchicalVe
     m_debListModel->m_packageMd5.append("1");
     m_debListModel->m_hierarchicalVerifyError = true;
 
-    Stub tmpStub;
-    tmpStub.set(ADDR(DebListModel, showHierarchicalVerifyWindow), stub_DebListModel_showHierarchicalVerifyWindow_DoNothing);
-
-    g_VerifyDeependErrCount = 0;
-    m_debListModel->bumpInstallIndex();
-    EXPECT_EQ(g_VerifyDeependErrCount, 1);
+    m_debListModel->slotInstallPackages();
     EXPECT_FALSE(m_debListModel->m_hierarchicalVerifyError);
 }
 
@@ -952,7 +944,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_ConfigReadOutput)
     int length = sizeof(buffer);
     bool isCommandExec = false;
     m_debListModel->slotConfigReadOutput(buffer.toStdString().c_str(), length, isCommandExec);
-    EXPECT_EQ(DebListModel::PackageOperationStatus::Operating,
+    EXPECT_EQ(Pkg::PackageOperationStatus::Operating,
               m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
 }
 
@@ -1019,7 +1011,7 @@ TEST_F(ut_DebListModel_test, onTransactionFinished_HierarchicalVerify_Failed)
 
     m_debListModel->slotTransactionFinished();
     EXPECT_EQ(nullptr, m_debListModel->m_currentTransaction);
-    EXPECT_EQ(DebListModel::DigitalSignatureError, m_debListModel->m_packageFailCode[m_debListModel->m_operatingPackageMd5]);
+    EXPECT_EQ(Pkg::DigitalSignatureError, m_debListModel->m_packageFailCode[m_debListModel->m_operatingPackageMd5]);
     EXPECT_TRUE(m_debListModel->m_hierarchicalVerifyError);
 
     delete g_transaction;
@@ -1066,9 +1058,8 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_refreshOperatingPackageStatus)
 {
     m_debListModel->m_operatingPackageMd5 = "deb";
     m_debListModel->m_packageOperateStatus.insert("deb", QApt::CommitError);
-    m_debListModel->refreshOperatingPackageStatus(DebListModel::PackageOperationStatus::Failed);
-    EXPECT_EQ(DebListModel::PackageOperationStatus::Failed,
-              m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
+    m_debListModel->refreshOperatingPackageStatus(Pkg::PackageOperationStatus::Failed);
+    EXPECT_EQ(Pkg::PackageOperationStatus::Failed, m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_slotDependsInstallTransactionFinished)
@@ -1103,8 +1094,8 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_slotUpWrongStatusRow)
     stub.set(ADDR(DebListModel, installNextDeb), model_installNextDeb);
     stub.set(ADDR(DebListModel, bumpInstallIndex), model_installNextDeb);
     stub.set(ADDR(Transaction, error), model_transaction_error);
-    m_debListModel->m_packageOperateStatus.insert("key", DebListModel::Failed);
-    m_debListModel->m_packageOperateStatus.insert("key1", DebListModel::Success);
+    m_debListModel->m_packageOperateStatus.insert("key", Pkg::PackageOperationStatus::Failed);
+    m_debListModel->m_packageOperateStatus.insert("key1", Pkg::PackageOperationStatus::Success);
     m_debListModel->slotUpWrongStatusRow();
     EXPECT_EQ(2, m_debListModel->m_packagesManager->m_packageMd5.size());
     EXPECT_EQ(2, m_debListModel->m_packagesManager->m_preparedPackages.size());
@@ -1122,10 +1113,11 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_onTransactionOutput)
 {
     Stub stub1;
     stub1.set(ADDR(QObject, sender), ut_sender);
-    m_debListModel->m_packageOperateStatus.insert("deb", DebListModel::Prepare);
+    m_debListModel->m_packageOperateStatus.insert("deb", Pkg::PackageOperationStatus::Prepare);
     m_debListModel->m_operatingPackageMd5 = "deb";
     m_debListModel->slotTransactionOutput();
-    EXPECT_EQ(DebListModel::Operating, m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
+    EXPECT_EQ(Pkg::PackageOperationStatus::Operating,
+              m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
     delete ut_sender();
 }
 
@@ -1250,12 +1242,12 @@ const QList<QString> ut_preparedPackages()
 TEST_F(ut_DebListModel_test, deblistmodel_UT_digitalVerifyFailed)
 {
     //    stub.set(ADDR(DebListModel,preparedPackages),ut_preparedPackages);
-    m_debListModel->digitalVerifyFailed(DebListModel::ErrorCode::DigitalSignatureError);
+    m_debListModel->digitalVerifyFailed(Pkg::ErrorCode::DigitalSignatureError);
     QStringList list;
     list << "/";
     m_debListModel->slotAppendPackage(list);
     m_debListModel->m_isDevelopMode = true;
-    m_debListModel->digitalVerifyFailed(DebListModel::ErrorCode::DigitalSignatureError);
+    m_debListModel->digitalVerifyFailed(Pkg::ErrorCode::DigitalSignatureError);
     EXPECT_EQ(1, m_debListModel->m_packageFailCode.size());
 }
 
