@@ -86,12 +86,12 @@ int stud_failedtoInt(bool *ok = nullptr)
     Q_UNUSED(ok);
     return 3;
 }
-bool stud_recheckPackagePath(QString )
+bool stud_recheckPackagePath(QString)
 {
     return true;
 }
 
-PackageDependsStatus stud_getPackageDependsStatus(const int )
+PackageDependsStatus stud_getPackageDependsStatus(const int)
 {
     return PackageDependsStatus::_break("package");
 }
@@ -99,20 +99,14 @@ PackageDependsStatus stud_getPackageDependsStatus(const int )
 class UT_SingleInstallpage : public UT_HEAD
 {
 public:
-    //添加日志
-    static void SetUpTestCase()
-    {
-        qDebug() << "SetUpTestCase" << endl;
-    }
-    static void TearDownTestCase()
-    {
-        qDebug() << "TearDownTestCase" << endl;
-    }
-    void SetUp() //TEST跑之前会执行SetUp
+    // 添加日志
+    static void SetUpTestCase() { qDebug() << "SetUpTestCase" << endl; }
+    static void TearDownTestCase() { qDebug() << "TearDownTestCase" << endl; }
+    void SetUp()  // TEST跑之前会执行SetUp
     {
         qDebug() << "SetUp" << endl;
     }
-    void TearDown() //TEST跑完之后会执行TearDown
+    void TearDown()  // TEST跑完之后会执行TearDown
     {
         delete page;
         delete model;
@@ -123,12 +117,12 @@ public:
 
 QVariant stu_data()
 {
-    return DebListModel::DependsOk;
+    return Pkg::DependsStatus::DependsOk;
 }
 
 QVariant stu_data1()
 {
-    return DebListModel::Success;
+    return Pkg::PackageOperationStatus::Success;
 }
 
 TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_total)
@@ -143,8 +137,8 @@ TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_total)
     stub.set(ADDR(DebFile, shortDescription), stud_singleshortDescription);
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stud_singlegetPackageDependsStatus);
     stub.set(ADDR(PackagesManager, packageInstallStatus), stud_singlepackageInstallStatus);
-    stub.set(ADDR(DebListModel, slotInstallPackages), stud_installPackages);
-    stub.set(ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
+    stub.set(decltype (&stud_installPackages)(&DebListModel::slotInstallPackages), stud_installPackages);
+    stub.set(decltype (&stud_singleuninstallPackage)(&DebListModel::slotUninstallPackage), stud_singleuninstallPackage);
     stub.set(ADDR(DebListModel, recheckPackagePath), stud_recheckPackagePath);
 
     model = new DebListModel();
@@ -295,8 +289,8 @@ TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_onWorkFinishedFailed)
     stub.set(ADDR(DebFile, shortDescription), stud_singleshortDescription);
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stud_singlegetPackageDependsStatus);
     stub.set(ADDR(PackagesManager, packageInstallStatus), stud_singlepackageInstallStatus);
-    stub.set(ADDR(DebListModel, slotInstallPackages), stud_installPackages);
-    stub.set(ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
+    stub.set((decltype(&stud_installPackages))ADDR(DebListModel, slotInstallPackages), stud_installPackages);
+    stub.set((decltype(&stud_singleuninstallPackage))ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
     stub.set(ADDR(DebListModel, recheckPackagePath), stud_recheckPackagePath);
 
     model = new DebListModel();
@@ -331,8 +325,8 @@ TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_onWorkFinishedSuccees)
     stub.set(ADDR(DebFile, shortDescription), stud_singleshortDescription);
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stud_singlegetPackageDependsStatus);
     stub.set(ADDR(PackagesManager, packageInstallStatus), stud_singlepackageInstallStatus);
-    stub.set(ADDR(DebListModel, slotInstallPackages), stud_installPackages);
-    stub.set(ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
+    stub.set((decltype(&stud_installPackages))ADDR(DebListModel, slotInstallPackages), stud_installPackages);
+    stub.set((decltype(&stud_singleuninstallPackage))ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
     stub.set(ADDR(QModelIndex, data), stu_data);
     stub.set(ADDR(DebListModel, recheckPackagePath), stud_recheckPackagePath);
     model = new DebListModel();
@@ -382,8 +376,8 @@ TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_initTabOrder)
     stub.set(ADDR(DebFile, shortDescription), stud_singleshortDescription);
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stud_singlegetPackageDependsStatus);
     stub.set(ADDR(PackagesManager, packageInstallStatus), stud_singlepackageInstallStatus);
-    stub.set(ADDR(DebListModel, slotInstallPackages), stud_installPackages);
-    stub.set(ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
+    stub.set((decltype(&stud_installPackages))ADDR(DebListModel, slotInstallPackages), stud_installPackages);
+    stub.set((decltype(&stud_singleuninstallPackage))ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
     stub.set(ADDR(QModelIndex, data), stu_data);
     stub.set(ADDR(DebListModel, recheckPackagePath), stud_recheckPackagePath);
     model = new DebListModel();
@@ -421,8 +415,8 @@ TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_paintEvent)
     stub.set(ADDR(DebFile, shortDescription), stud_singleshortDescription);
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stud_singlegetPackageDependsStatus);
     stub.set(ADDR(PackagesManager, packageInstallStatus), stud_singlepackageInstallStatus);
-    stub.set(ADDR(DebListModel, slotInstallPackages), stud_installPackages);
-    stub.set(ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
+    stub.set((decltype(&stud_installPackages))ADDR(DebListModel, slotInstallPackages), stud_installPackages);
+    stub.set((decltype(&stud_singleuninstallPackage))ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
     stub.set(ADDR(QModelIndex, data), stu_data);
     stub.set(ADDR(DebListModel, recheckPackagePath), stud_recheckPackagePath);
     model = new DebListModel();
@@ -447,8 +441,8 @@ TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_slotDependPackages)
     stub.set(ADDR(DebFile, shortDescription), stud_singleshortDescription);
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stud_singlegetPackageDependsStatus);
     stub.set(ADDR(PackagesManager, packageInstallStatus), stud_singlepackageInstallStatus);
-    stub.set(ADDR(DebListModel, slotInstallPackages), stud_installPackages);
-    stub.set(ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
+    stub.set((decltype(&stud_installPackages))ADDR(DebListModel, slotInstallPackages), stud_installPackages);
+    stub.set((decltype(&stud_singleuninstallPackage))ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
     stub.set(ADDR(QModelIndex, data), stu_data);
     stub.set(ADDR(DebListModel, recheckPackagePath), stud_recheckPackagePath);
     model = new DebListModel();
@@ -457,13 +451,13 @@ TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_slotDependPackages)
     model->m_packagesManager->m_preparedPackages.append("test1");
     page = new SingleInstallPage(model);
     usleep(100 * 1000);
-    //    QMap<QByteArray, QPair<QList<DependInfo>, QList<DependInfo>>> dependPackages;
-    DependInfo info;
+    //    QMap<QByteArray, QPair<QList<Pkg::DependInfo>, QList<Pkg::DependInfo>>> dependPackages;
+    Pkg::DependInfo info;
     info.packageName = "libopencl1";
     info.version = "1.0";
-    QList<DependInfo> list;
+    QList<Pkg::DependInfo> list;
     list.append(info);
-    QPair<QList<DependInfo>, QList<DependInfo>> pair;
+    QPair<QList<Pkg::DependInfo>, QList<Pkg::DependInfo>> pair;
     pair.first.append(list);
     pair.second.append(list);
     //    dependPackages.insert("deb", pair);
