@@ -15,20 +15,14 @@
 class DRoundBgFrame_UT : public UT_HEAD
 {
 public:
-    //添加日志
-    static void SetUpTestCase()
-    {
-        qDebug() << "SetUpTestCase" << endl;
-    }
-    static void TearDownTestCase()
-    {
-        qDebug() << "TearDownTestCase" << endl;
-    }
-    void SetUp() //TEST跑之前会执行SetUp
+    // 添加日志
+    static void SetUpTestCase() { qDebug() << "SetUpTestCase" << endl; }
+    static void TearDownTestCase() { qDebug() << "TearDownTestCase" << endl; }
+    void SetUp()  // TEST跑之前会执行SetUp
     {
         qDebug() << "SetUp" << endl;
     }
-    void TearDown() //TEST跑完之后会执行TearDown
+    void TearDown()  // TEST跑完之后会执行TearDown
     {
     }
     DRoundBgFrame *frame;
